package com.hw.mes.controller;

import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.web.page.TableDataInfo;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.common.security.utils.SecurityUtils;
import com.hw.mes.domain.MesMaterialBom;
import com.hw.mes.domain.MesProductPlan;
import com.hw.mes.domain.MesProductPlanDetail;
import com.hw.mes.domain.vo.MesProductPlanDetailVo;
import com.hw.mes.service.IMesMaterialBomService;
import com.hw.mes.service.IMesProductOrderService;
import com.hw.mes.service.IMesProductPlanDetailService;
import com.hw.mes.service.IMesProductPlanService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * MES对外提供接口Controller
 *
 * @author Yinq
 * @date 2024-01-30
 */
@RestController
@RequestMapping("/api")
public class MesApiController extends BaseController {
    @Autowired
    private IMesMaterialBomService mesMaterialBomService;

    @Autowired
    private IMesProductPlanService productPlanService;

    @Autowired
    private IMesProductPlanDetailService productPlanDetailService;

    /**
     * 查询物料BOM信息列表
     */
//    @RequiresPermissions("mes:materialBom:list")
    @GetMapping("/getMaterialBoms")
    public AjaxResult getMaterialBoms(MesMaterialBom mesMaterialBom) {
        String ancestors = mesMaterialBom.getAncestors();
        ancestors = "0," + ancestors;
        mesMaterialBom.setAncestors(ancestors);
        List<MesMaterialBom> list = mesMaterialBomService.selectMesMaterialBomJoinList(mesMaterialBom);
        return success(list);
    }


    /**
     * 查询车间派工信息列表表（适用于各楼层各工序）
     */
//    @RequiresPermissions("mes:materialBom:list")
    @GetMapping("/getProductPlans")
    public TableDataInfo getProductPlans(MesProductPlan mesProductPlan) {
        startPage();
        List<MesProductPlan> list = productPlanService.selectMesProductPlanJoinList(mesProductPlan);
        return getDataTable(list);
    }


    /**
     * 生成生产计划明细（适用于1楼、四楼装配工位）
     */
    @Log(title = "生产计划明细", businessType = BusinessType.INSERT)
    @PostMapping(("/insertProductPlanDetails"))
    public AjaxResult insertProductPlanDetails(@Validated @RequestBody MesProductPlanDetailVo mesProductPlanDetailVo) {
        return success(productPlanDetailService.insertMesProductPlanDetails(mesProductPlanDetailVo));
    }


    /**
     * 根据生产计划ID查询车间生产计划明细列表（适用于1楼、四楼装配工位）
     */
//    @RequiresPermissions("mes:materialBom:list")
    @GetMapping("/getProductPlanDetails")
    public TableDataInfo getProductPlanDetails(MesProductPlanDetail mesProductPlanDetail) {
        startPage();
        List<MesProductPlanDetail> list = productPlanDetailService.selectMesProductPlanDetailList(mesProductPlanDetail);
        return getDataTable(list);
    }


    /**
     * 开始生产计划明细（适用于1楼、四楼装配工位），在生成计划明细时一条一条的开始
     */
    @Log(title = "生产计划明细", businessType = BusinessType.START)
    @PostMapping(("/startProductPlanDetail"))
    public AjaxResult startProductPlanDetail(@RequestBody MesProductPlanDetail mesProductPlanDetail) {
        return success(productPlanDetailService.startMesProductPlanDetail(mesProductPlanDetail));
    }


    /**
     * 完成生产计划明细（适用于各工序）
     */
    @Log(title = "生产计划明细", businessType = BusinessType.COMPLETE)
    @PostMapping(("/completeProductPlanDetail"))
    public AjaxResult completeProductPlanDetail(@RequestBody MesProductPlanDetail mesProductPlanDetail) {
        return success(productPlanDetailService.completeMesProductPlanDetail(mesProductPlanDetail));
    }


    /**
     * 获取最新的生产计划明细，在刚登录页面打开时获取根据工位ID获取，如果点击生产计划则根据生产计划ID获取(适用于四楼激光切割、折弯焊接和五楼)
     */
//    @RequiresPermissions("mes:baseAttachInfo:query")
    @GetMapping(value = "/getNewestProductPlanDetail")
    public AjaxResult getNewestProductPlanDetail(MesProductPlanDetail queryProductPlanDetail) {
        if (queryProductPlanDetail.getPlanId() == null) {
            Long stationId = SecurityUtils.getStationId();
            queryProductPlanDetail.setStationId(stationId);
        }
        return success(productPlanDetailService.selectNewestMesProductPlanDetail(queryProductPlanDetail));
    }


    /**
     * 开始下一生产计划明细（适用于四楼激光切割、折弯焊接和五楼），开始时才生成一条计划明细
     */
    @Log(title = "生产计划明细", businessType = BusinessType.START)
    @PostMapping(("/startNextProductPlanDetail"))
    public AjaxResult startNextProductPlanDetail(@RequestBody MesProductPlanDetail mesProductPlanDetail) {
        return success(productPlanDetailService.startNextMesProductPlanDetail(mesProductPlanDetail));
    }


}
